@@ -11,6 +11,7 @@
 #include <cstring>
 
 #include "common/logging.hpp"
+#include "common/pisp_common.h"
 
 using namespace libpisp;
 
@@ -22,7 +23,6 @@ BackEnd::BackEnd(Config const &config, PiSPVariant const &variant)
 	if (config_.max_tile_width > max_tile_width)
 		PISP_LOG(fatal, "Configured max tile width " << config_.max_tile_width << " exceeds " << max_tile_width);
 
-	smart_resize_.resize(2, { 0, 0 });
 	smart_resize_dirty_ = 0;
 
 	const char *env = std::getenv("LIBPISP_BE_CONFIG_FILE");
@@ -61,7 +61,10 @@ void BackEnd::GetGlobal(pisp_be_global_config &global) const
 void BackEnd::SetInputFormat(pisp_image_format_config const &input_format)
 {
 	be_config_.input_format = input_format;
-	be_config_extra_.dirty_flags_bayer |= PISP_BE_BAYER_ENABLE_INPUT;
+	if (PISP_IMAGE_FORMAT_THREE_CHANNEL(input_format.format))
+		be_config_extra_.dirty_flags_bayer |= PISP_BE_BAYER_ENABLE_INPUT;
+	else
+		be_config_extra_.dirty_flags_rgb |= PISP_BE_RGB_ENABLE_INPUT;
 	retile_ = true;
 }
 
