@@ -20,11 +20,12 @@ public:
 		Interval2 crop;
 	};
 	CropStage(char const *name, Stage *upstream, Config const &config, int struct_offset);
-	virtual Length2 GetOutputImageSize() const;
-	virtual void PushStartUp(int output_start, Dir dir);
-	virtual int PushEndDown(int input_end, Dir dir);
-	virtual void PushEndUp(int output_end, Dir dir);
-	virtual void PushCropDown(Interval interval, Dir dir);
+	virtual Length2 GetOutputImageSize() const override;
+	virtual void PushStartUp(int output_start, Dir dir) override;
+	virtual int PushEndDown(int input_end, Dir dir) override;
+	virtual void PushEndUp(int output_end, Dir dir) override;
+	virtual void PushCropDown(Interval interval, Dir dir) override;
+	bool GetBranchInactive() const override;
 
 private:
 	Config config_;
